/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload 
 * @submodule auto-download-view
 */

(function() {
var AutoDownloadView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var UiUtils = dixim.common.UiUtils;
var escape = dixim.xml.escape;
var $ = dixim.ctt.jQuery;

/**
 * @class AutoDownloadView
 * @constructor
 * @param {Object} configs
 */
AutoDownloadView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AutoDownloadView, EventTarget);
dixim.contents.AutoDownloadView = AutoDownloadView;
prototype = AutoDownloadView.prototype;
superConstructor = AutoDownloadView.superConstructor;

var SELECT = 'select';
var OPERATE = 'operate';
var REFRESH = 'refresh';
var SETTING = 'setting';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._title = _('download_menu_auto_download');
    this._contentName = new this._contentNameClosure();
    this._selectedTasks = {};
};

/**
 * @method show
 */
prototype.show = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div id="auto_download_field" class="contents_inner">',
        '</div>',
        '</div>',
    ].join(''));

    UiUtils.cleanActionSettingBar();
    UiUtils.cleanActionBar();
    UiUtils.setActionBar('ab_select', dixim.proxy(this._clickSelect, this));
    UiUtils.setActionBar('ab_operate', dixim.proxy(this._clickOperate, this));
    UiUtils.disableActionBar('ab_select');
    UiUtils.showActionSettingBar('ac_refresh', dixim.proxy(this._clickRefresh, this));
    UiUtils.showActionSettingBar('ac_setting', dixim.proxy(this._clickSetting, this));

    this._setContentName(this._title);
    $('.btn_prev').off('click').show().on('click', dixim.proxy(this._clickPrev, this));
};

/**
 * @method hide
 */
prototype.hide = function() {
   $('.rootPage').empty();
};

prototype._contentNameClosure = function() {
    var stack = [];

    return {
        push: function(name) {
            $('.art_tit').text(name);
            stack.push(name);
        },
        pop: function() {
            stack.pop();
            $('.art_tit').text(stack[stack.length - 1]);
        },
    }
};

prototype._setContentName = function(name) {
    this._contentName.push(name);
};

prototype._getReservationTime = function(info) {
    var min;
    var hour;

    if(info.reservationType === 'asap') {
        return _('auto_download_asap');
    }

    min = Math.floor(info.timedReservationStartTime % 60);
    hour = Math.floor(info.timedReservationStartTime / 60);
    min = (min < 10) ? '0' + min: '' + min;
    hour = (hour < 10) ? '0' + hour: '' + hour;
    return [hour, min].join(':');
};

prototype._getQuality = function(info) {
    if (info.sdFirst) {
        return _('auto_download_quality_low');
    } else {
        return _('auto_download_quality_high');
    }
};

prototype.addRow = function(data) {
    var rowSelector;

    $('#auto_download_field').append([
        '<div id="task_', data.taskId, '" class="auto-download-list">',
        '<div>',
        '<table>',
        '<colgroup>',
        '<col span="1" class="checkbox">',
        '<col span="1" class="list_info">',
        '<col span="1" class="checkbox">',
        '</colgroup>',
        '<tr>',
        '<td>',
        '<label class="select-pointer">',
        '<input type="checkbox" />', '<span>', '</span>',
        '</label>',
        '</td>',
        '<td>',
        '<dl class="list_8em">',
        '<dt class="list_title_s">', _('auto_download_src_title'), '</dt>',
        '<dd>', escape(data.srcFriendlyName), '(', data.srcContainerTitle, ')', '</dd>',
        '</dl>',
        '<dl class="list_8em">',
        '<dt class="list_title_s">', _('auto_download_dst_title'), '</dt>',
        '<dd>', data.dstContainerPath, '</dd>',
        '</dl>',
        '<dl class="list_8em">',
        '<dt class="list_title_s">', _('auto_download_reservation_time'), '</dt>',
        '<dd>', this._getReservationTime(data), '</dd>',
        '</dl>',
        '</td>',
        '<td>',
        '<div class="not-open-task open-task-btn">', '</div>',
        '</td>',
        '</tr>',
        '</table>',
        '<div class="auto-download-task-descriptions txt_s">',
        '<dl class="list_8em">',
        '<dt class="task-description-title">', '<span>', _('auto_download_quality_title'), '</span>', '</dt>',
        '<dd>', '<span>', this._getQuality(data), '</span>', '</dd>',
        '</dl>',
        '<dl class="list_8em">',
        '<dt class="task-description-title">', '<span>', _('auto_download_registered_filter'), '</span>', '</dt>',
        '<dd name="task_filters">', '</dd>',
        '</dl>',
        '</div>',
        '</div>',
        '</div>',
    ].join(''));

    rowSelector = $('#auto_download_field > div:last-child');

    rowSelector.find('.auto-download-task-descriptions').hide();
    rowSelector.find('[type="checkbox"]').on('change', data, dixim.proxy(this._changeCheckbox, this));
    rowSelector.find('.open-task-btn').on('click', this._clickInfo);
};

prototype.addFilter = function(task_id, filter_name) {
    $(['#task_', task_id, ' [name="task_filters"]'].join('')).append([
        '<span>', escape(filter_name), '</span>',
    ].join(''));
};

prototype._changeCheckbox = function(e) {
    if (e.currentTarget.checked) {
        this._selectedTasks[e.data.taskId] = e.data;
    } else {
        delete this._selectedTasks[e.data.taskId]
    }
};

prototype.noRow = function() {
    this.error(_('auto_download_no_tasks'));
};

prototype.error = function(text) {
    $('#auto_download_field').html([
        '<div class="txt_none error-text-field">',
        '<span>', text, '</span>',
        '</div>',
    ].join(''));
};

prototype.checkActionBarStatus = function() {
    if ($('#auto_download_field [type="checkbox"]').length < 1) {
        UiUtils.disableActionBar('ab_select');
    } else {
        UiUtils.enableActionBar('ab_select');
    }
};

prototype.switchSelect = function() {
    var checkboxSelector = $('.contents_inner [type="checkbox"]');
    var numberOfNotChecked = checkboxSelector.not(':checked').length;

    checkboxSelector.prop('checked', (numberOfNotChecked > 0)).trigger('change');
};

prototype.cleanContent = function() {
    this._selectedTasks = {};
    $('#auto_download_field').empty();
};

prototype._clickRefresh = function() {
    this.dispatchEvent(new Event(REFRESH));
};

prototype._clickSetting = function() {
    this.dispatchEvent(new Event(SETTING));
};

prototype._clickOperate = function() {
    this.dispatchEvent(new Event(OPERATE, {taskList: this._selectedTasks}));
};

prototype._clickSelect = function() {
    this.dispatchEvent(new Event(SELECT));
};

prototype._clickInfo = function() {
    var rowSelector = $(this).closest('.auto-download-list');

    if (rowSelector.find('.auto-download-task-descriptions').is(':visible')) {
        $(this).removeClass('open-task').addClass('not-open-task');
    } else {
        $(this).removeClass('not-open-task').addClass('open-task');
    }
    rowSelector.find('.auto-download-task-descriptions').slideToggle();
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

}());
