/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule auto-download-wizard-dialog-controller
 */

(function() {
var AutoDownloadWizardDialogController;
var prototype;
var superConstructor;
var AutoDownloadWizardSelectSrcDialogView = dixim.autoDownload.AutoDownloadWizardSelectSrcDialogView;
var AutoDownloadWizardSelectDstDialogView = dixim.autoDownload.AutoDownloadWizardSelectDstDialogView;
var AutoDownloadWizardHowtoDialogView = dixim.autoDownload.AutoDownloadWizardHowtoDialogView;
var AutoDownloadWizardFilterDialogView = dixim.autoDownload.AutoDownloadWizardFilterDialogView;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var EventTarget = dixim.event.EventTarget;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var ApiClientAutoDownload = dixim.common.ApiClientAutoDownload;
var FilterEditDialogController = dixim.autoDownload.FilterEditDialogController;
var Enum = dixim.ctt.util.Enum;

/**
 * @class AutoDownloadWizardDialogController
 * @constructor
 * @param {Object} configs
 */
AutoDownloadWizardDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AutoDownloadWizardDialogController, EventTarget);
dixim.autoDownload.AutoDownloadWizardDialogController = AutoDownloadWizardDialogController;
prototype = AutoDownloadWizardDialogController.prototype;
superConstructor = AutoDownloadWizardDialogController.superConstructor;

var NEXT = 'next';
var CLOSE = 'close';
var SELECT_SERVER = 'selectServer';
var SELECT_DIRECTORY = 'selectDirectory';
var PREV = 'prev';
var APPLY = 'apply';
var UPDATE = 'update';
var ADD = 'add';
var CHANGE = 'change';
var ROOT_OBJECTID = 'FS-Folder';

var FilterMode = Enum.fetch('DIALOG');
var apiClientSessionManager = dixim.common.apiClientSessionManager;

var BROWSING_STATUS = {
    STOPPED: 0,
    STOPPING: 1,
    BROWSING: 2,
};

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'auto-download-wizard-dialog'].join('');

    this._model = new ApiClientAutoDownload();
    this._model.addEventListener('fetchSrcList', this._successFetchSrcList, this);
    this._model.addEventListener('fetchSrcListError', this._errorFetchSrcList, this);
    this._model.addEventListener('browseSrc', this._successBrowseSrc, this);
    this._model.addEventListener('browseSrcError', this._errorBrowseSrc, this);
    this._model.addEventListener('fetchDstStorageList', this._successFetchDstStorageList, this);
    this._model.addEventListener('fetchDstStorageListError', this._errorFetchDstStorageList, this);
    this._model.addEventListener('browseDst', this._successBrowseDst, this);
    this._model.addEventListener('browseDstError', this._errorBrowseDst, this);
    this._model.addEventListener('fetchFilterList', this._successFetchFilterList, this);
    this._model.addEventListener('fetchFilterListError', this._errorFetchFilterList, this);
    this._model.addEventListener('setTask', this._successSetTask, this);
    this._model.addEventListener('setTaskError', this._errorSetTask, this);
    this._model.addEventListener('changeTask', this._successChangeTask, this);
    this._model.addEventListener('changeTaskError', this._errorChangeTask, this);
    this._model.addEventListener('linkTaskFilter', this._successLinkTaskFilter, this);
    this._model.addEventListener('linkTaskFilterError', this._errorLinkTaskFilter, this);
    this._model.addEventListener('unlinkTaskFilter', this._successUnlinkTaskFilter, this);
    this._model.addEventListener('unlinkTaskFilterError', this._errorUnlinkTaskFilter, this);
    this._model.addEventListener('fetchCondList', this._successFetchCondList, this);
    this._model.addEventListener('fetchCondListError', this._errorFetchCondList, this);

    this._title = configs.title || '';
    this._selectSrcView;
    this._selectDstView;
    this._howtoView;
    this._filterView;
    this._requestingFilterInfo;
    this._isUpdateFilter = false;

    this._contentHeight = ['300', 'px'].join('');
    this._taskInfo = configs.taskInfo || null;
    this._isEdit = (this._taskInfo !== null);
    this._configs = {};
    this._browseRequestData;
    this._browsingStack = [];
    this._browsingStatus = BROWSING_STATUS.STOPPED;
    this._containerCount = 0;
    this._filterInfo;
    this._storagePaths = [];
};

/**
 * @method start
 */
prototype.start = function() {
    if (this._isEdit) {
        this._viewHowto();
        this._configs.src = {
            objectId: this._taskInfo.srcContainerId,
            title: this._taskInfo.srcContainerTitle,
        };
        this._configs.serverInfo = {
            udn: this._taskInfo.srcUdn,
            icons: [],
            friendlyName: this._taskInfo.srcFriendlyName,
            type: this._taskInfo.srcType,
        };
    } else {
        this._viewSelectSrc();
    }
};

/**
 * @method stop
 */
prototype.stop = function() {
    if (typeof this._selectSrcView !== 'undefined') this._selectSrcView.hide();
    if (typeof this._selectDstView !== 'undefined') this._selectDstView.hide();
    if (typeof this._howtoView !== 'undefined') this._howtoView.hide();
    if (typeof this._filterView !== 'undefined') this._filterView.hide();
};

prototype._viewSelectSrc = function(sources) {
    var query = {};

    query.title = this._title;
    query.contentHeight = this._contentHeight;
    query.doubleDialog = true;

    delete this._configs.serverInfo;
    this._browseRequestData;
    this._browsingStack = [];
    this._browsingStatus = BROWSING_STATUS.STOPPED;

    this._selectSrcView = new AutoDownloadWizardSelectSrcDialogView(query);
    this._selectSrcView.addEventListener(SELECT_SERVER, this._clickServer, this);
    this._selectSrcView.addEventListener(SELECT_DIRECTORY, this._clickDirectory, this);
    this._selectSrcView.addEventListener(PREV, this._clickPrev, this);
    this._selectSrcView.addEventListener(NEXT, this._clickNext, this);
    this._selectSrcView.addEventListener(CLOSE, this._clickClose, this);

    this._selectSrcView.show();
    this._selectSrcView.changeCheckbox();
    apiClientSessionManager.cancelAll();
    this._model.fetchSrcList();
};

prototype._successFetchSrcList = function(e) {
    var sources = e.args.sources;
    var sourcesLen = sources.length;

    if (sourcesLen === 0) {
        this._selectSrcView.noRow();
        return;
    }

    for (var i = 0; i < sourcesLen; i += 1) {
        this._selectSrcView.addRow(sources[i]);
    }
};

prototype._errorFetchSrcList = function(e) {
    this._errorDialog(_('auto_download_select_src_fetch_error_description'));
    this._clickClose();
};

prototype._clickServer = function(e) {
    this._browsingStack.push('0');
    this._configs.serverInfo = e.args;
    this._browseAfterStop();
};

prototype._viewBrowseSrcContents = function(objectId) {
    if (typeof this._configs.serverInfo === 'undefined') return;
    this._selectSrcView.cleanList();
    this._selectSrcView.setReturnButton(PREV);
    this._selectSrcView.changeCheckbox();
    this._browsingStatus = BROWSING_STATUS.BROWSING;
    this._browseRequest(objectId, 0);
};

prototype._browseRequest = function(objectId, startingIndex) {
    var query = {};

    if (typeof this._configs.serverInfo === 'undefined' || typeof this._configs.serverInfo.udn === 'undefined') return;

    query.udn = this._configs.serverInfo.udn;
    query.objectId = objectId || '0';
    query.startingIndex = startingIndex;

    this._browseRequestData = query;
    this._model.browseSrc(query);
};

prototype._successBrowseSrc = function(e) {
    var objects = e.args.objects;
    var objectsLen = objects.length;
    var totalReturned = e.args.numberReturned;
    var totalMatches = e.args.totalMatches;
    var startingIndex = this._browseRequestData.startingIndex;
    var objects = e.args.objects;
    var isStopping = (this._browsingStatus === BROWSING_STATUS.STOPPING);
    var isEndBrowsing = ((totalReturned + startingIndex) === totalMatches);
    var isMatchId = true;

    if (objects.length !== 0) isMatchId = (this._browseRequestData.id === objects[0].parentId);

    if (totalMatches === 0) {
        this._selectSrcView.noItemRow();
        this._browsingStatus = BROWSING_STATUS.STOPPED;
        return;
    }
    if (isStopping || (!isMatchId)) {
        this._browsingStatus = BROWSING_STATUS.STOPPED;
        return;
    }

    for (var i = 0; i < objectsLen; i += 1) {
        this._selectSrcView.addItemRow(objects[i]);
    }

    if (isEndBrowsing) {
        this._browsingStatus = BROWSING_STATUS.STOPPED;
        return;
    }

    totalReturned += this._browseRequestData.starting_index;
    this._browseRequest(this._browseRequestData.id, totalReturned);
};

prototype._browseAfterStop = function(id) {
    if (this._browsingStatus === BROWSING_STATUS.BROWSING) {
        this._browsingStatus = BROWSING_STATUS.STOPPING;
    }

    if (this._browsingStatus !== BROWSING_STATUS.STOPPED) {
        setTimeout(dixim.proxy(function() {
            this._browseAfterStop(id)
        }, this), 100);
    } else {
        this._viewBrowseSrcContents(id);
    }
};

prototype._errorBrowseSrc = function() {
    this._errorDialog(_('auto_download_select_src_browse_error_description'));
    this._clickClose();
};

prototype._clickDirectory = function(e) {
    this._browsingStack.push(e.args.objectId);
    this._browseAfterStop(e.args.objectId);
};

prototype._clickPrev = function() {
    var objectId;

    this._browsingStack.pop();
    objectId = this._browsingStack.pop();

    if (typeof objectId === 'undefined') {
        this._viewSelectSrc();
    } else {
        this._browsingStack.push(objectId);
        this._browseAfterStop(objectId);
    }
};

prototype._clickNext = function(e) {
    if (typeof this._configs.serverInfo === 'undefined') {
        this._configs.serverInfo = e.args;
        this._configs.src = {
            objectId: '0',
            class: 'object.container',
            title: 'root',
        };
    } else {
        this._configs.src = e.args;
    }
    this._viewSelectDst();
};

prototype._viewSelectDst = function() {
    var query = {};

    query.title = this._title;
    query.contentHeight = this._contentHeight;
    query.doubleDialog = true;

    this._browseRequestData;
    this._browsingStack = [];
    this._browsingStatus = BROWSING_STATUS.STOPPED;

    this._selectDstView = new AutoDownloadWizardSelectDstDialogView(query);
    this._selectDstView.addEventListener(SELECT_DIRECTORY, this._clickDirectorySelectDst, this);
    this._selectDstView.addEventListener(PREV, this._clickPrevSelectDst, this);
    this._selectDstView.addEventListener(NEXT, this._clickNextSelectDst, this);
    this._selectDstView.addEventListener(CLOSE, this._clickClose, this);

    this._selectDstView.show();
    this._selectDstView.changeCheckbox();
    this._browsingStack.push(ROOT_OBJECTID);
    this._model.fetchDstStorageList();
};

prototype._successFetchDstStorageList = function(e) {
    var storages = e.args.storages;

    this._storagePaths = [];
    for (var i = 0, len = storages.length; i < len; i += 1) {
        this._storagePaths.push(storages[i].containerId);
    }
    this._browseDstAfterStop(ROOT_OBJECTID);
};

prototype._errorFetchDstStorageList = function() {
    this._errorDialog(_('auto_download_select_dst_browse_error_description'));
    this._clickClose();
};

prototype._viewBrowseDstContents = function(objectId) {
    this._selectDstView.cleanList();
    this._selectDstView.setReturnButton(PREV);
    this._selectDstView.changeCheckbox();
    this._browsingStatus = BROWSING_STATUS.BROWSING;
    this._containerCount = 0;
    this._browseDstRequest(objectId, 0);
};

prototype._browseDstRequest = function(objectId, startingIndex) {
    var query = {};

    query.objectId = objectId || ROOT_OBJECTID;
    query.browseFlag = 'BrowseDirectChildren';
    query.startingIndex = startingIndex;

    this._browseRequestData = query;
    this._model.browseDst(query);
};

prototype._successBrowseDst = function(e) {
    var objects = e.args.objects;
    var objectsLen = objects.length;
    var totalReturned = e.args.numberReturned;
    var totalMatches = e.args.totalMatches;
    var startingIndex = this._browseRequestData.startingIndex;
    var objects = e.args.objects;
    var isStopping = (this._browsingStatus === BROWSING_STATUS.STOPPING);
    var isEndBrowsing = ((totalReturned + startingIndex) === totalMatches);
    var isMatchId = true;

    if (objects.length !== 0) isMatchId = (this._browseRequestData.objectId === e.args.session.request.objectId);

    if (totalMatches === 0) {
        this._selectDstView.noRow();
        this._browsingStatus = BROWSING_STATUS.STOPPED;
        return;
    }
    if (isStopping || (!isMatchId)) {
        this._browsingStatus = BROWSING_STATUS.STOPPED;
        return;
    }

    for (var i = 0; i < objectsLen; i += 1) {
        if (this._browseRequestData.objectId === ROOT_OBJECTID) {
            if (this._storagePaths.indexOf(objects[i].objectId) === -1) {
                continue;
            }
        }
        if (objects[i].class === 'object.container') {
            this._selectDstView.addRow(objects[i]);
            this._containerCount += 1;
        }
    }

    if (isEndBrowsing) {
        this._browsingStatus = BROWSING_STATUS.STOPPED;
        if (this._containerCount === 0) {
            this._selectDstView.noRow();
        }
        return;
    }

    totalReturned += this._browseRequestData.starting_index;
    this._browseRequest(this._browseRequestData.objectId, totalReturned);
};

prototype._browseDstAfterStop = function(id) {
    if (this._browsingStatus === BROWSING_STATUS.BROWSING) {
        this._browsingStatus = BROWSING_STATUS.STOPPING;
    }

    if (this._browsingStatus !== BROWSING_STATUS.STOPPED) {
        setTimeout(dixim.proxy(function() {
            this._browseDstAfterStop(id)
        }, this), 100);
    } else {
        this._selectDstView.cleanList();
        this._viewBrowseDstContents(id);
    }
};

prototype._errorBrowseDst = function() {
    this._errorDialog(_('auto_download_select_dst_browse_error_description'));
    this._clickClose();
};

prototype._clickDirectorySelectDst = function(e) {
    this._browsingStack.push(e.args.objectId);
    this._browseDstAfterStop(e.args.objectId);
};

prototype._clickPrevSelectDst = function() {
    var objectId;

    this._browsingStack.pop();
    objectId = this._browsingStack.pop();

    if (typeof objectId === 'undefined') {
        this._viewSelectSrc();
    } else {
        this._browsingStack.push(objectId);
        this._browseDstAfterStop(objectId);
    }
};

prototype._clickNextSelectDst = function(e) {
    this._configs.dst = e.args;
    this._viewHowto();
};


prototype._viewHowto = function() {
    var query = {};

    query.title = this._title;
    query.taskInfo = this._taskInfo;
    query.contentHeight = this._contentHeight;
    query.doubleDialog = true;

    this._howtoView = new AutoDownloadWizardHowtoDialogView(query);
    this._howtoView.addEventListener(PREV, this._clickPrevHowto, this);
    this._howtoView.addEventListener(NEXT, this._clickNextHowto, this);
    this._howtoView.addEventListener(CLOSE, this._clickClose, this);

    this._howtoView.show();
    this._howtoView.setReturnButton(PREV);
};

prototype._clickPrevHowto = function() {
    this._howtoView.hide();
    if (!this._isEdit) {
        this._viewSelectDst();
    }
};

prototype._clickNextHowto = function(e) {
    this._configs.howto = e.args;
    this._viewFilter();
};

prototype._viewFilter = function() {
    var query = {};

    query.title = this._title;
    query.contentHeight = this._contentHeight;
    query.doubleDialog = true;
    query.taskInfo = this._taskInfo;
    query.serverInfo = this._configs.serverInfo;

    this._filterView = new AutoDownloadWizardFilterDialogView(query);
    this._filterView.addEventListener(CLOSE, this._clickClose, this);
    this._filterView.addEventListener(PREV, this._clickPrevFilter, this);
    this._filterView.addEventListener(APPLY, this._clickApplyFilter, this);
    this._filterView.addEventListener(CHANGE, this._clickChangeFilter, this);
    this._filterView.addEventListener(ADD, this._clickAddFilter, this);

    this._filterView.show();
    this._filterView.setReturnButton(PREV);
    this._model.fetchFilterList();
};

prototype._getFilterIds = function(taskId, filters) {
    var filtersLen = filters.length;
    var taskIds;
    var taskIdsLen;
    var filterIds = [];

    for (var i = 0; i< filtersLen; i += 1) {
        taskIds = filters[i].taskIds;
        taskIdsLen = taskIds.length;
        for (var j = 0; j < taskIdsLen; j += 1) {
            if (taskId === taskIds[j]) {
                filterIds.push(filters[i].filterId);
            }
        }
    }
    return filterIds;
};

prototype._successFetchFilterList = function(e) {
    var filters = e.args.filters;
    var taskIds;

    if (this._isUpdateFilter) {
        this._filterView.registerFilters(filters);
        this._filterView.putFilterList();
        this._isUpdateFilter = false;
        return;
    }
    this._filterView.registerFilters(filters);
    this._filterView.addFilterList();
    if (this._isEdit) {
        this._taskInfo.filters = this._getFilterIds(this._taskInfo.taskId, filters);
        this._filterView.setFilters(this._taskInfo.filters);
    }
};

prototype._errorFetchFilterList = function() {
    this._errorDialog(_('auto_download_filter_fetch_error'));
    this._clickClose();
};

prototype._clickChangeFilter = function(e) {
    var filters = e.args.filters;
    var query = {};

    if (filters.length !== 1) {
        this._errorDialog(_('auto_download_filter_one_only_error'));
        return;
    }

    this._filterInfo = filters[0];
    query.filterId = filters[0].filterId;
    this._model.fetchCondList(query);
};

prototype._successFetchCondList = function(e) {
    var query = {};
    var controller;

    query.filterInfo = {
        id: this._filterInfo.filterId,
        title: this._filterInfo.filterName,
        combCond: this._filterInfo.combCond,
    };

    query.conds = e.args.conds;
    query.mode = FilterMode.EDIT;
    controller = new FilterEditDialogController(query);
    controller.addEventListener(UPDATE, this._updateFilterList, this);

    controller.start();
};

prototype._errorFetchCondList = function() {
    this._errorDialog(_('auto_download_filter_setting_fetch_cond_error'));
};

prototype._clickAddFilter = function(e) {
    var controller;
    var query = {};

    query.mode = FilterMode.ADD;
    controller = new FilterEditDialogController(query);
    controller.addEventListener(UPDATE, this._updateFilterList, this);

    controller.start();
};

prototype._clickApplyFilter = function(e) {
    this._filterView.startIndicator();
    this._configs.filters = e.args.filters;
    this._applyTask();
};

prototype._clickPrevFilter = function() {
    this._filterView.hide();
    this._viewHowto();
};

prototype._applyTask = function() {
    var query = {};

    query.sdFirst = this._configs.howto.sdFirst || false;

    if (typeof this._configs.howto.startTime !== 'undefined') {
        query.reservationType = 'TIMED'
        query.timedReservationStartTime = this._configs.howto.startTime;
    } else {
        query.reservationType = 'ASAP'
    }

    if (!this._isEdit) {
        query.srcUdn = this._configs.serverInfo.udn;
        query.srcContainerId = this._configs.src.objectId;
        query.dstContainerId = this._configs.dst.objectId;
        this._model.setTask(query);
    } else {
        query.taskId = this._taskInfo.taskId;
        this._model.changeTask(query);
    }
};

prototype._successSetTask = function(e) {
    var taskId = e.args.taskId;
    var filters = this._configs.filters.filter(function(x, i, self) {
        return self.indexOf(x) === i;
    });
    var filtersLen = filters.length;
    var query = {};

    query.taskId = taskId;

    this._requestingFilterInfo = {};
    this._requestingFilterInfo.len = filtersLen;
    this._requestingFilterInfo.error = false;
    if (filtersLen === 0) {
        this._completeLinkUnlinkTaskFilter();
        return;
    }

    for (var i = 0; i < filtersLen; i += 1) {
        query.filterId = filters[i];
        this._model.linkTaskFilter(query);
    }

};

prototype._errorSetTask = function(e) {
    var str = _('auto_download_set_task_error');

    switch(e.args.errorCode) {
        case 479:
        case 480:
        case 481:
        case 482:
        case 483:
        case 484:
        case 485:
        case 486:
        case 487:
        case 488:
        case 500:
            str = _(['auto_download_set_task_error_', e.args.errorCode].join(''));
            break;
        default:
            break;
    }
    this._clickClose();
    this._errorDialog(str);
};

prototype._updateFilterList = function() {
    this._filterView.cleanFilterList();
    this._isUpdateFilter = true;
    this._model.fetchFilterList();
};

prototype._subtractArray = function(arr1, arr2) {
    var result = [];
    var flag;
    var arr1Len = arr1.length;
    var arr2Len = arr2.length;

    for (var i = 0; i < arr1Len; i += 1) {
        flag = true;
        for (var j = 0; j < arr2Len; j += 1) {
            if (arr1[i] === arr2[j]) {
                flag = false;
                break;
            }
        }
        if (flag) result.push(arr1[i]);
    }
    return result;
};

prototype._successChangeTask = function() {
    var delList;
    var delListLen;
    var addList;
    var addListLen;
    var query = {};
    var tmpList;

    tmpList = this._subtractArray(this._taskInfo.filters, this._configs.filters);
    delList = tmpList.filter(function(x, i, self) {
        return self.indexOf(x) === i;
    });
    delListLen = delList.length;

    tmpList = this._subtractArray(this._configs.filters, this._taskInfo.filters);
    addList = tmpList.filter(function(x, i, self) {
        return self.indexOf(x) === i;
    });
    addListLen = addList.length;

    this._requestingFilterInfo = {};
    this._requestingFilterInfo.len = delListLen + addListLen;
    this._requestingFilterInfo.error = false;

    if (this._requestingFilterInfo.len === 0) {
        this._completeLinkUnlinkTaskFilter();
        return;
    }

    query.taskId = this._taskInfo.taskId;

    for (var i = 0; i < delListLen; i += 1) {
        query.filterId = delList[i];
        this._model.unlinkTaskFilter(query);
    }
    for (var i = 0; i < addListLen; i += 1) {
        query.filterId = addList[i];
        this._model.linkTaskFilter(query);
    }
};

prototype._errorChangeTask = function(e) {
    var str = _('auto_download_set_task_error');

    switch(e.args.errorCode) {
        case 488:
            str = _(['auto_download_set_task_error_', e.args.errorCode].join(''));
            break;
        default:
            break;
    }
    this._clickClose();
    this._errorDialog(str);
};

prototype._successLinkTaskFilter = function() {
    this._requestingFilterInfo.len -= 1;
    if (this._requestingFilterInfo.len === 0) {
        this._completeLinkUnlinkTaskFilter();
    }
};

prototype._errorLinkTaskFilter = function() {
    this._requestingFilterInfo.len -= 1;
    this._requestingFilterInfo.error = true;
    if (this._requestingFilterInfo.len === 0) {
        this._completeLinkUnlinkTaskFilter();
    }
};

prototype._successUnlinkTaskFilter = function() {
    this._requestingFilterInfo.len -= 1;
    if (this._requestingFilterInfo.len === 0) {
        this._completeLinkUnlinkTaskFilter();
    }
};

prototype._errorUnlinkTaskFilter = function() {
    this._requestingFilterInfo.len -= 1;
    this._requestingFilterInfo.error = true;
    if (this._requestingFilterInfo.len === 0) {
        this._completeLinkUnlinkTaskFilter();
    }
};

prototype._completeLinkUnlinkTaskFilter = function() {
    if (this._requestingFilterInfo.error) {
        this._errorDialog(_('auto_download_link_task_filter_error'));
        this._clickClose();
        return;
    }
    this._filterView.stopIndicator();
    this.dispatchEvent(new Event(UPDATE));
};

prototype._errorDialog = function(text) {
    var dialogTitle = (this._isEdit) ? _('auto_download_operation_change_task') : _('auto_download_operation_add_task');
    var query = {};
    var dialog;

    query.id = this._id;
    query.title = dialogTitle;
    query.description = text;
    query.doubleDialog = true;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

prototype._clickClose = function() {
    this.stop();
};

}());
