/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule auto-download-wizard-select-dst-dialog-view
 */

(function() {
var AutoDownloadWizardSelectDstDialogView;
var prototype;
var superConstructor;
var ModalDialogView = dixim.common.ModalDialogView;
var Configs = dixim.ctt.Configs;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

/**
 * @class AutoDownloadWizardSelectDstDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
AutoDownloadWizardSelectDstDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(AutoDownloadWizardSelectDstDialogView, ModalDialogView);
dixim.autoDownload.AutoDownloadWizardSelectDstDialogView = AutoDownloadWizardSelectDstDialogView;
superConstructor = AutoDownloadWizardSelectDstDialogView.superConstructor;
prototype = AutoDownloadWizardSelectDstDialogView.prototype;

var NEXT = 'next';
var SELECT_DIRECTORY = 'selectDirectory';

var TEMPLATE_BODY_CONTENT = [
    '<div id="auto-download-description-field" class="description-field dlg_main_msg">',
    '<span>', '${description}', '</span>',
    '</div>',
    '<div id="auto-download-parent" class="modal_hd_btns">', '</div>',
    '<div id="auto-download-dst-list" class="list-field dlg_scroll list_next">',
    '<table>', '</table>',
    '</div>',
].join('');

var CONTENTS_IMAGES = {
    nosecureV: [Configs.get('imagePath'), '/ico_list_nosecure_v.png'].join(''),
    nosecureM: [Configs.get('imagePath'), '/ico_list_nosecure_m.png'].join(''),
    nosecureP: [Configs.get('imagePath'), '/ico_list_nosecure_p.png'].join(''),
    folder: [Configs.get('imagePath'), '/ico_list_folder.png'].join('')
}

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'auto-download-wizard-select-dst-dialog-'].join('');

    configs.title = configs.title;

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${description}', _('auto_download_select_dst_description'));

    configs.contentHeight = configs.contentHeight || 'auto';
    configs.buttons = [
        {text: _('dialog_return_menu'), click: dixim.proxy(this.hide, this)},
        {text: _('dialog_next'), click: dixim.proxy(this._clickNext, this)},
    ];

    this._srcInfo = [];

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._render = function() {
    superConstructor.prototype._render.call(this);
};

prototype.addRow = function(data) {
    var icon = this._getContentImage(data);
    var rowSelector;

    $('#auto-download-dst-list table').append([
        '<tr class="auto-download-task-field-row">', '<td class="select-server-checkbox">',
        '<label class="select-pointer">', '<input type="checkbox" />', '<span>', '</span>', '</label>',
        '</td>', '<td class="select-directory">',
        '<img src="', icon, '" width="40px" />',
        '<span class="info-title-text">', data.title, '</span>',
        '</td>', '</tr>',
    ].join(''));

    rowSelector = $('#auto-download-dst-list table tr:last-child');

    if (data['class'].indexOf('item') !== -1) {
        rowSelector.find('label').removeClass('select-pointer');
        rowSelector.find('[type="checkbox"]').prop('disabled', true);
        rowSelector.addClass('noactive');
    } else {
        rowSelector.find('td').not('.select-server-checkbox').on('click', data, dixim.proxy(this._clickDirectory, this));
        rowSelector.find('[type="checkbox"]').on('click', data, dixim.proxy(this._clickCheckbox, this));
    }
};

prototype.noRow = function() {
    $('#auto-download-dst-list').addClass('error-text-field txt_none');
    $('#auto-download-dst-list').html(['<span>', _('auto_download_select_src_no_contents'), '</span>'].join(''));
};

prototype._getContentImage = function(info) {
    var srcPath;

    if (info['class'].indexOf('item') !== -1) {
        if (/object.item.videoItem.*/.test(info['class'])) {
            srcPath = CONTENTS_IMAGES['nosecureV'];
        } else if (/object.item.audioItem.*/.test(info['class'])) {
            srcPath = CONTENTS_IMAGES['nosecureM'];
        } else if (/object.item.imageItem.*/.test(info['class'])) {
            srcPath = CONTENTS_IMAGES['nosecureP'];
        }
    } else {
        srcPath = CONTENTS_IMAGES['folder'];
    }
    return srcPath;
};

prototype.changeCheckbox = function() {
    var checkboxSelector = $('#auto-download-dst-list table [type="checkbox"]:checked');

    if (checkboxSelector.length === 1) {
        this.enableButton(_('dialog_next'));
    } else {
        this.disableButton(_('dialog_next'));
    }
};

prototype._removeSrcList = function(data) {
    for (var i = 0, len = this._srcInfo.length; i < len; i += 1) {
        if (typeof data.objectId !== 'undefined' && typeof this._srcInfo[i].objectId !== 'undefined') {
            if (this._srcInfo[i].objectId === data.objectId) {
                this._srcInfo.splice(i, 1);
                break;
            }
        } else if (typeof data.udn !== 'undefined' && typeof this._srcInfo[i].udn !== 'undefined') {
            if (this._srcInfo[i].udn === data.udn) {
                this._srcInfo.splice(i, 1);
                break;
            }
        }
    }
};

prototype.cleanList = function() {
    $('#auto-download-dst-list').removeClass('error-text-field txt_none');
    $('#auto-download-dst-list').html(['<table>', '</table>'].join(''));
};

prototype._clickServer = function(e) {
    this.dispatchEvent(new Event(SELECT_SERVER, e.data));
};

prototype._clickDirectory = function(e) {
    this.dispatchEvent(new Event(SELECT_DIRECTORY, e.data));
};

prototype._clickCheckbox = function(e) {
    this.changeCheckbox();
    if (e.target.checked) {
        this._srcInfo.push(e.data);
    } else {
        this._removeSrcList(e.data);
    }
};

prototype._clickNext = function() {
    this.dispatchEvent(new Event(NEXT, this._srcInfo[0]));
};

}());
