/**
 * @module dixim
 * @submodule common
 */
dixim.namespace('dixim.common');

/**
 * @module common
 * @submodule error-modal-dialog-view
 */

(function() {
var ErrorModalDialogView;
var superConstructor;
var prototype;
var ModalDialogView = dixim.common.ModalDialogView;
var _ = dixim.ctt.ResourceBundle.get;

/**
 * @class ErrorModalDialogView
 * @constructor
 * @param {Object} configs
 */
ErrorModalDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(ErrorModalDialogView, ModalDialogView);
dixim.common.ErrorModalDialogView = ErrorModalDialogView;
prototype = ErrorModalDialogView.prototype;
superConstructor = ErrorModalDialogView.superConstructor;

var TEMPLATE_BODY_CONTENT = [
    '<div id="', '${id}', '" class="error-dialog-body-content dlg_main_msg error-text-field">',
    '<span class="error-text">', '${description}', '</span>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'error-moda-dialog-'].join('');
    configs.bodyContent = TEMPLATE_BODY_CONTENT.
        replace('${id}', configs.id).
        replace('${description}', configs.description);

    configs.closeButton = dixim.proxy(this.hide, this);
    configs.buttons = [
        {
            text: _('dialog_close'),
            click: dixim.proxy(this.hide, this),
        },
    ];

    superConstructor.prototype._initialize.call(this, configs);
};

prototype.addErrorList = function(name, description) {
    var bodySelector = $(['#body-content-', this._id].join(''));
    var errorField = bodySelector.find('[name="progress_error_field"]');

    if (errorField.length === 0) {
        bodySelector.append([
            '<div name="progress_error_field" class="dl_tbl dlg_scroll">',
            '</div>',
        ].join(''));
        errorField = bodySelector.find('[name="progress_error_field"]');
    }
    errorField.append([
        '<dl>',
        '<dt>', '<span>', name, '</span>', '</dt>',
        '<dd>', '<span>', description, '</span>', '</dt>',
        '</dl>',
    ].join(''));
};

prototype.removeClass = function(className) {
    var bodySelector = $(['#body-content-', this._id].join(''));

    bodySelector.find(['.', className].join('')).removeClass(className);
};

}());
