/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule permission-default-setting-view
 */

(function() {
var PermissionDefaultSettingView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var UiUtils = dixim.common.UiUtils;
var $ = dixim.ctt.jQuery;

/**
 * @class PermissionDefaultSettingView
 * @constructor
 * @param {Object} configs
 */
PermissionDefaultSettingView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(PermissionDefaultSettingView, EventTarget);
dixim.server.PermissionDefaultSettingView = PermissionDefaultSettingView;
prototype = PermissionDefaultSettingView.prototype;
superConstructor = PermissionDefaultSettingView.superConstructor;

var PREV = 'prev';
var APPLY = 'apply';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._title = _('server_permission_menu_default');
    this._uiUtils = UiUtils;
};

/**
 * @method show
 */
prototype.show = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<div class="dl_tbl">',
        '<dl>',
        '<dt>', _('server_default_permission_title'), '</dt>',
        '<dd>',
        '<p>', _('server_default_permission_detail'), '</p>',
        '<label id="default_setting_allow" class="select-pointer">',
        '<input type="radio" name="ntp" value="automatic" />',
        '<span>', _('server_default_permission_allow'), '</span>',
        '</label>',
        '<label id="default_setting_deny" class="select-pointer">',
        '<input type="radio" name="ntp" value="automatic" />',
        '<span>', _('server_default_permission_deny'), '</span>',
        '</label>',
        '</dd>',
        '</dl>',
        '</div>',
        '</div>',
        '</div>',
    ].join(''));

    this._uiUtils.cleanActionSettingBar();
    this._uiUtils.cleanActionBar();
    this._uiUtils.setActionBar('ab_apply', dixim.proxy(this._clickApply, this));

    $('.art_tit').text(this._title);
    $('.btn_prev').show().one('click', dixim.proxy(this._clickPrev, this));
};

/**
 * @method hide
 */
prototype.hide = function() {
    $('.rootPage').empty();
};

prototype.setSetting = function(isAllow) {
    if (typeof isAllow === 'undefined') {
        $('#default_setting_allow [type="radio"]').prop('checked', false);
        $('#default_setting_deny [type="radio"]').prop('checked', false);
        return;
    }
    if (isAllow) {
        $('#default_setting_allow [type="radio"]').prop('checked', true);
    } else {
        $('#default_setting_deny [type="radio"]').prop('checked', true);
    }
};

prototype._clickApply = function() {
    var checkId = $('.contents_inner [type="radio"]:checked').closest('label').prop('id');

    this.dispatchEvent(new Event(APPLY, {isAllow: (checkId === 'default_setting_allow')}));
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

}());
