/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule filter-list-dialog-controller
 */

(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var ErrorDialog = dixim.ctt.ErrorDialog;
var FilterListDialogView = dixim.ctt.ad.FilterListDialogView;
var FilterSettingDialogController = dixim.ctt.ad.FilterSettingDialogController;
var FilterSettingDialogEditController = dixim.ctt.ad.FilterSettingDialogEditController;
var ConfirmationDialogController = dixim.ctt.ad.ConfirmationDialogController;
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;
var _ = dixim.ctt.ResourceBundle.get;

var FilterListDialogController;
var prototype;

/**
 * @class FilterListDialogController
 * @constructor
 * @param {Object} configs
 * @param {AutoDownloadApiClient} [configs.model]
 */
FilterListDialogController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(FilterListDialogController, EventTarget);
dixim.ctt.ad.FilterListDialogController = FilterListDialogController;
prototype = FilterListDialogController.prototype;

/**
 * Triggered when the deletion has been done.
 *
 * @event close
 * @param {Event} event
 * @param {Object} event.args
 * @param {Object} event.args.deleted true if the deletion is completed, otherwise false.
 */
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Object} configs.targetItems
 * @param {ContentsTransferApiClient} [configs.model]
 */
prototype._initialize = function(configs) {
  configs = configs || {};

  this._model = new AutoDownloadApiClient();
  this._view = new FilterListDialogView(configs);
  this._session = null;
  this._queue = [];
  this._finish = configs.finish;
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  v.addEventListener('cancel', this._didClickCancel, this);
  v.addEventListener('edit', this._didClickEdit, this);
  v.addEventListener('delete', this._didClickDelete, this);
  v.addEventListener('selectAll', this._didClickSelectAll, this);
  v.addEventListener('unselectAll', this._didClickUnselectAll, this);
  v.addEventListener('add', this._didClickAdd, this);

  v.show();
};

prototype._didClickEdit = function() {
  var query = {};
  var edit_dialog;

  if ($('#filter-list [type="checkbox"]:checked').length === 1) {
    query.filterId = $('#filter-list [type="checkbox"]:checked').val();
    query.afterClose = dixim.proxy(function() {
      this.reload();
    }, this);
    edit_dialog = new FilterSettingDialogEditController(query);
    edit_dialog.start();
  } else {
    prototype._showErrorDialog("error_dialog_does_not_change_one_filter");
  }
};

prototype._didClickDelete = function() {
  var dialog_query;
  var checked_list = [];

  if ($('#filter-list input[type="checkbox"]:checked').length === 0) {
    prototype._showErrorDialog("error_dialog_selected_no_filter");
  } else {
    $('#filter-list input[type="checkbox"]:checked').each(function() {
      checked_list.push($(this).val());
    });
    dialog_query = {};
    dialog_query.processing = dixim.proxy(function() {
      var query = {};
      var query_success_func = dixim.proxy(function() {
        this.reload();
      }, this);
      var checked_list_length = checked_list.length;
      var delete_complete = dixim.proxy(function() {
        cdc.destroy();
        this.reload();
        cdc.finish();
      }, this);
      var delete_filter_error =dixim.proxy(function() {
        this._showErrorDialog("ctt_error_dialog_default");
      }, this);

      for (var i = 0; i < checked_list_length; i += 1) {
      query.filterId = checked_list[i];
      checked_list[i] = null;
      if (i === (checked_list.length-1)) {
        query.success = query_success_func;
       }
      query.error = delete_filter_error;
      query.complete = delete_complete;
      this._model.deleteFilter(query);
       }
    }, this);
    dialog_query.description = _("ad_dialog_filter_confirm_delete_dialog_description");
    dialog_query.isDelete = true;
    cdc = new ConfirmationDialogController(dialog_query);

    cdc.start();
  }
};

prototype._didClickSelectAll = function() {
  $('#filter-list input[type="checkbox"]').prop("checked", true);
};

prototype._didClickUnselectAll = function() {
  $('#filter-list input[type="checkbox"]').prop("checked", false);
};

prototype._didClickAdd = function() {
  var query = {};
  var _setting;

  query.finish = dixim.proxy(function() {
    this.reload();
  }, this);
  _setting = new FilterSettingDialogController(query);
  _setting.start();
};

prototype._didClickCancel = function() {
  this._finish();
  this._view.destroy();
  this.dispatchEvent(new Event(CLOSE));
};

/**
 * @method reload
 */
prototype.reload = function() {
  $('#filter-list').empty();
  this._view._didCreateFilterTable();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

/**
 * @method _showErrorDialog
 * @private
 * @param {String} error error ID.
 */
prototype._showErrorDialog = function(error) {
  var dialog;
  var query = {type: error};

  if (!!this._modal) {
    this._modal.destroy();
    this._modal = null;
  }
  if (typeof error.title !== "undefined") {
    query.title = error.title;
  }
  if (typeof error.description !== "undefined") {
    query.description = error.description;
  }

  dialog = new ErrorDialog(query);
  dialog.addEventListener('close', this._didCloseModalDialog, this);

  dialog.show();
  this._modal = dialog;
};

prototype._didCloseModalDialog = function(e) {
  var args = e.args;

  if (this._modal === args.dialog) {
    this._modal.destroy();
    this._modal = null;
  }
};

}());
