/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule filter-setting-dialog-controller
 */

(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var FilterSettingDialogView = dixim.ctt.ad.FilterSettingDialogView;
var ConfirmationDialogController = dixim.ctt.ad.ConfirmationDialogController;
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;
var ErrorDialog = dixim.ctt.ErrorDialog;

var FilterSettingDialogController;
var prototype;

/**
 * @class FilterSettingDialogController
 * @constructor
 * @param {Object} configs
 * @param {AutoDownloadApiClient} [configs.model]
 */
FilterSettingDialogController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(FilterSettingDialogController, EventTarget);
dixim.ctt.ad.FilterSettingDialogController = FilterSettingDialogController;
prototype = FilterSettingDialogController.prototype;

/**
 * Triggered when the deletion has been done.
 *
 * @event close
 * @param {Event} event
 * @param {Object} event.args
 * @param {Object} event.args.deleted true if the deletion is completed, otherwise false.
 */
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Object} configs.targetItems
 * @param {ContentsTransferApiClient} [configs.model]
 */
prototype._initialize = function(configs) {
  configs = configs || {};

  this._model = new AutoDownloadApiClient();
  this._view = new FilterSettingDialogView(configs);
  this._data = {};
  this._finish = configs.finish || function(){return;};
  this._afterClose = configs.afterClose || function(){return;};
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  v.addEventListener('cancel', this._didClickCancel, this);
  v.addEventListener('submit', this._didClickSubmit, this);
  v.addEventListener('alldelete', this._didClickAllDelete, this);

  v.show();
};

prototype._didCreateCondsList = function() {
  var list = [];
  var checkAndSetCondition = function(name) {
    $(['#table_',name,' [type="text"]'].join('')).each(function() {
      var query = {};
      var this_val = $(this).val();
      var date_array;

      if (this_val !== '') {
        switch(name) {
        case 'title':
          query.name = 1;
          break;
        case 'channel':
          query.name = 3;
          break;
        case 'description':
          query.name = 2;
          break;
        case 'date':
          query.name = 7;
          date_array = this_val.split('/');
          this_val = [date_array[0],date_array[1],date_array[2]].join('');
          break;
        default:
          break;
        }
        query.op = parseInt($(this).parent('td').next().find('select').val(), 10);
        query.value = this_val;
        list.push(query);
      }
    });
  };
  var checkAndSetGenreCondition = function(name) {
    var query = {};
    var sum = 0;

    $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
      if ($(this).is(':checked')) {
          sum += parseInt($(this).val(), 10);
      }
    });
    query.name = 4;
    query.op = 1;
    query.value = sum;
    list.push(query);
  };
  var checkAndSetDayOfTheWeekCondition = function(name) {
    var query = {};
    var sum = 0;

    $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
      if ($(this).is(':checked')) {
          sum += parseInt($(this).val(), 10);
      }
    });
    query.name = 8;
    query.op = 1;
    query.value = sum;
    list.push(query);
  };
  var checkAndSetDurationCondition = function(name) {
    $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
      var duration_id = $(this).prop('id');
      var input_val = $(this).next().val();
      var error_val;
      var minute;
      var time;
      var query = {};

      if (input_val !== '') {
        minute = parseInt(input_val.split(':')[0], 10) * 60 + parseInt(input_val.split(':')[1], 10);
        time = minute * 60 * 1000;
        query.name = 5;
        if (duration_id === 'checkbox_longer') {
          query.op = 11;
          query.value = time;
          list.push(query);
        } else if (duration_id === 'checkbox_shorter') {
          query.op = 9;
          query.value = time;
          list.push(query);
        } else if (duration_id == 'checkbox_equal') {
          error_val = parseInt($(this).parent('td').next().find('input').val(), 10) * 60 * 1000;
          if (error_val !== '') {
            query.op = 7;
            query.value = time;
            query.value2 = error_val;
            list.push(query);
           }
         }
      }
    });
  };
  var checkAndSetRecordingCondition = function(name) {
    var query = {};
    var input_text;
    var time_array;

    if ($(['#table_',name,' [type="checkbox"]'].join('')).is(':checked')) {
      input_text = $(['#input_',name.split('_')[1],'_time'].join(''));
      time_array = $(input_text).val().split(':');
      query.name = (name === 'recording_start_time') ? 9: 10;
      query.op =  7;
      query.value = parseInt(time_array[0], 10) * 60 + parseInt(time_array[1], 10);
      query.value2 = parseInt($(input_text).next().next().val(), 10);
      list.push(query);
    }
  };
  var checkAndSetBroadcastWaveCondition = function(name) {
    var query = {};
    var sum = 0;

    $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
      if ($(this).is(':checked')) {
        sum += parseInt($(this).val(), 10);
      }
    });
    query.name = 11;
    query.op = 1;
    query.value = sum;
    list.push(query);
  };
  var checkAndSetCopyCountCondition = function(name) {
    $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
      var query = {};
      var this_id = $(this).prop('id');

      if ($(this).is(':checked')) {
        query.name = 6;
        if (this_id === 'checkbox_larger' || this_id === 'checkbox_shorter') {
          query.op = parseInt($(this).parent('td').next().next().find('select').val(), 10);
          query.value = $(this).parent('td').next().find('select').val();
        } else if (this_id === 'checkbox_same') {
          query.op = 7;
          query.value = $(this).parent('td').next().find('select').val();
         }
        list.push(query);
       }
    });
  };

  $('#setting_coupling_condition #exist_state').each(function() {
    var name = $(this).parent('span').prop('id').slice(0,-11);
    switch(name) {
    case 'title':
      checkAndSetCondition(name);
      break;
    case 'channel':
      checkAndSetCondition(name);
      break;
    case 'genre':
      checkAndSetGenreCondition(name);
      break;
    case 'description':
      checkAndSetCondition(name);
      break;
    case 'date':
      checkAndSetCondition(name);
      break;
    case 'day_of_the_week':
      checkAndSetDayOfTheWeekCondition(name);
      break;
    case 'duration':
      checkAndSetDurationCondition(name);
      break;
    case 'recording_start_time':
      checkAndSetRecordingCondition(name);
      break;
    case 'recording_end_time':
      checkAndSetRecordingCondition(name);
      break;
    case 'broadcast_wave':
      checkAndSetBroadcastWaveCondition(name);
      break;
    case 'copy_count':
      checkAndSetCopyCountCondition(name);
      break;
    default:
      break;
    }
  });

  return list;
};

prototype._didClickSubmit = function() {
  var filterName = $('#input_filter_name').val();

  if (filterName === "") {
    this._view._showErrorDialog("error_dialog_no_filter_name");
    return;
  }
  this._data.filterName = filterName;
  this._data.combCond = $('#radio_and_attribute').is(':checked') ? "AND": "OR";
  this._data.success = dixim.proxy(function(e) {
    var add_cond_query = {};
    var conds_list = this._didCreateCondsList();
    var add_cond_error = dixim.proxy(function() {
        this._showErrorDialog("ctt_error_dialog_default");
      }, this);

    add_cond_query.filterId = e.args.filterId;
    for (var i = 0; i < conds_list.length; i += 1) {
      add_cond_query = $.extend(add_cond_query, conds_list[i]);
      add_cond_query.error = add_cond_error;
      this._model.addCond(add_cond_query);
    }
  }, this);
  this._data.error = dixim.proxy(function() {
    this._showErrorDialog("ctt_error_dialog_default");
  }, this);
  this._data.complete = dixim.proxy(function(e) {
    e.args.filterName = this._data.filterName;
    this._finish(e);
    this._view.destroy();
    this.dispatchEvent(new Event(CLOSE));
  }, this);

  this._model.addFilter(this._data);
};

prototype._didClickAllDelete = function() {
  var query = {};
  var cdc;
  var v = this._view;

  query.processing = function() {
    v._didCreateCouplingConditions();
    this.finish();
  };
  query.isDelete = true;
  cdc = new ConfirmationDialogController(query);

  cdc.start();
};

prototype._didClickCancel = function() {
  this._view.destroy();
  this._afterClose();
  this.dispatchEvent(new Event(CLOSE));
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

/**
 * @method _showErrorDialog
 * @private
 * @param {String} error error ID.
 */
prototype._showErrorDialog = function(error) {
  var dialog;
  var query = {type: error};

  if (!!this._modal) {
    this._modal.destroy();
    this._modal = null;
  }
  if (typeof error.title !== "undefined") {
    query.title = error.title;
  }
  if (typeof error.description !== "undefined") {
    query.description = error.description;
  }

  dialog = new ErrorDialog(query);
  dialog.addEventListener('close', this._didCloseModalDialog, this);

  dialog.show();
  this._modal = dialog;
};

prototype._didCloseModalDialog = function(e) {
  var args = e.args;

  if (this._modal === args.dialog) {
    this._modal.destroy();
    this._modal = null;
  }
};

}());
