/**
 * @module ctt
 * @submodule search-box-controller
 */
(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var SearchBoxView = dixim.ctt.SearchBoxView;

var SearchBoxController;
var prototype;

/**
 * @class SearchBoxController
 * @extends EventTarget
 * @uses Event
 * @uses SearchBoxView
 * @constructor
 * @param {Object} configs
 */
SearchBoxController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(SearchBoxController, EventTarget);
dixim.ctt.SearchBoxController = SearchBoxController;
prototype = SearchBoxController.prototype;

/**
 * Triggered when the user attempted to search for keyword.
 * 
 * @event search
 */
var SEARCH = 'search';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  this._view = new SearchBoxView({containerNode: configs.containerNode});
};

/**
 * @method start
 */
prototype.start = function() {
  this._view.addEventListener('search', this._didSearch, this);
  this._view.show();
};

/**
 * @method _didSearch
 */
prototype._didSearch = function(e) {
  var args = e.args;
  var val = args.keyword;

  if (!!!val) return;
  this.dispatchEvent(new Event(SEARCH, {keyword: val}));
};

}());
