/**
 * @module ctt
 * @submodule transfer-history-view
 */
(function() {
var Event = dixim.event.Event;
var ModalDialogView = dixim.ctt.ModalDialogView;
var Template = dixim.ctt.util.Template;
var TickerView = dixim.ctt.TickerView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var TransferHistoryView;
var prototype;
var superConstructor;

/**
 * @class TransferHistoryView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
TransferHistoryView = function(configs) {
  ModalDialogView.call(this, configs);
};
dixim.inherit(TransferHistoryView, ModalDialogView);
dixim.ctt.TransferHistoryView = TransferHistoryView;
prototype = TransferHistoryView.prototype;
superConstructor = TransferHistoryView.superConstructor;

var TEMPLATE_CONTENT_BOX = '<div class="ctt-transfer-history-view-wrapper" />';

var TEMPLATE_BODY_CONTENT = ['<div class="ctt-transfer-history-view">',
                               '<div class="ctt-transfer-history-view-message-wrapper">',
                                 '<div class="ctt-transfer-history-view-error"></div>',
                               '</div>',
                               '<div class="ctt-transfer-history-view-history-list"></div>',
                             '</div>'].join('');

var TEMPLATE_LOADING = Template.LOADING_OVERLAY;

/**
 * Triggered when the close button was clicked.
 *
 * @event close
 */
var CLOSE = 'close';

/**
 * Triggered when the clear button was clicked.
 *
 * @event clear
 */
var CLEAR = 'clear';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;

  configs  = configs || {};

  buttons = [
    {
      'text': _('ctt_dialog_button_label_close'),
      click: $.proxy(this._didClickClose, this)
    },
    {
      'text': _('ctt_transfer_history_view_button_label_clear'),
      click: $.proxy(this._didClickClear, this),
      align: 'left'
    }
  ];

  configs.title = _('ctt_transfer_history_view_title');
  configs.contentBox = configs.contentBox || TEMPLATE_CONTENT_BOX;
  configs.bodyContent = configs.bodyContent || TEMPLATE_BODY_CONTENT;
  configs.buttons = buttons;

  this._ticker = null;
  this._loading = null;

  superConstructor.prototype._initialize.call(this, configs);
};

prototype._didRenderDialog = function(e) {
  var v = this._view;
  var ticker;

  this._loading = $(TEMPLATE_LOADING);

  ticker = new TickerView({
    containerNode: $('.ctt-transfer-history-view-error', v),
    type: 'error'
  });
  ticker.addEventListener('hide', this._didChangeTickerVisibility, this);
  ticker.addEventListener('show', this._didChangeTickerVisibility, this);
  this._ticker = ticker;

  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didOpenDialog = function(e) {
  superConstructor.prototype._didOpenDialog.call(this, e);
  this._adjustListHeight();
};

prototype._didChangeTickerVisibility = function(e) {
  this._adjustListHeight();
};

prototype._adjustListHeight = function() {
  var v = this._view;
  var list;
  var desc;

  list = $('.ctt-transfer-history-view-history-list', v);
  desc = $('.ctt-transfer-history-view-message-wrapper', v);
  list.height(Math.floor(v.height() - desc.outerHeight(true)));
  list.resize();
};

prototype._didTitlebarCloseButtonClick = function(e) {
  e.preventDefault();
  this._closeDialog();
};

prototype._didClickClose = function(e) {
  this._closeDialog();
};

prototype._closeDialog = function() {
  this.dispatchEvent(new Event(CLOSE));
};

prototype._didClickClear = function(e) {
  this.dispatchEvent(new Event(CLEAR));
};

/**
 * @method showError
 * @param {String} errot
 */
prototype.showError = function(error) {
  this._showError(error);
};

prototype._showError = function(error) {
  this._ticker.setText(error);
  this._ticker.show();
};

prototype.showActivityIndicator = function() {
  var p = this._view;
  var o = this._loading;

  this.disableButtons();
  o.appendTo(p).width(p.innerWidth()).height(p.innerHeight()).show();
};

prototype.hideActivityIndicator = function() {
  this._loading.hide(100).detach();
  this.enableButtons();
};

prototype.getBodyContent = function() {
  return $('.ctt-transfer-history-view-history-list', this._view);
};

}());