/**
 * @module dixim
 * @submodule common
 */
dixim.namespace('dixim.common');

/**
 * @module common
 * @submodule deletion-modal-dialog-view
 */

(function() {
var DeletionModalDialogView;
var prototype;
var superConstructor;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var ModalDialogView = dixim.common.ModalDialogView;
var $ = dixim.ctt.jQuery;

/**
 * @class DeletionModalDialogView
 * @constructor
 * @param {Object} configs
 */
DeletionModalDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(DeletionModalDialogView, ModalDialogView);
dixim.common.DeletionModalDialogView = DeletionModalDialogView;
prototype = DeletionModalDialogView.prototype;
superConstructor = DeletionModalDialogView.superConstructor;

var CLOSE = 'close';
var YES = 'yes';
var COMPLETE = 'complete';

var TEMPLATE_BODY_CONTENT = [
    '<div>',
    '<div class="ctt-deletion-view-description dlg_main_msg">', '${description}', '</div>',
    '<div class="ctt-deletion-view">',
    '<div class="ctt-deletion-view-progress txt_gray">', '</div>',
    '</div>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    var buttonText;

    configs = configs || {};

    buttonText = configs.buttonText || _('dialog_delete');

    configs.id = configs.id || '';
    configs.id = [configs.id, 'deletion-modal-dialog-'].join('');
    configs.bodyContent = TEMPLATE_BODY_CONTENT.
        replace('${description}', configs.description);

    configs.closeButton = dixim.proxy(this.hide, this);
    configs.buttons = [
        {
            text: _('dialog_close'),
            click: dixim.proxy(this.hide, this),
        },
        {
            text: buttonText,
            click: dixim.proxy(this._clickYes, this),
        },
    ];

    this._contents = $.merge([], configs.contents);
    this._contentsLen = this._contents.length;
    this._nameKey = configs.nameKey || '';

    superConstructor.prototype._initialize.call(this, configs);
};

prototype.decrementDescription = function() {
    var data = this._contents.shift();
    var name = '';

    if (typeof data === 'undefined') {
        this.hide();
        this.stopSpecifiedIndicator($('.ctt-deletion-view-description'));
        this.dispatchEvent(new Event(COMPLETE));
        return;
    }

    if (this._nameKey in data) {
        name = data[this._nameKey];
    }
    $('.ctt-deletion-view-description').html([
        _('deletion_progress_description'),
    ].join(''));
    $('.ctt-deletion-view-progress').text(_('deletion_progress_info', name, this._contentsLen - this._contents.length, this._contentsLen));
};

prototype._clickYes = function() {
    this.decrementDescription();
    this.startSpecifiedIndicator($('.ctt-deletion-view-description'));
    this.dispatchEvent(new Event(YES));
};

}());
