/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule contents-menu-controller
 */

(function() {
var ContentsMenuController;
var prototype;
var superConstructor;
var ContentsMenuView = dixim.contents.ContentsMenuView;
var EventTarget = dixim.event.EventTarget;
var UiFunctionManager = dixim.ctt.util.UiFunctionManager;
var Configs = dixim.ctt.Configs;
var ResourceBundle = dixim.ctt.ResourceBundle;
var ContentsController = dixim.contents.ContentsController;

/**
 * @class ContentsMenuController
 * @constructor
 * @param {Object} configs
 */
ContentsMenuController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(ContentsMenuController, EventTarget);
dixim.contents.ContentsMenuController = ContentsMenuController;
prototype = ContentsMenuController.prototype;
superConstructor = ContentsMenuController.superConstructor;

UiFunctionManager.set('contents');

var MEDIA_CONTENTS = 'mediaContents';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    ResourceBundle.reset();
    Configs.set('resourceBundlePath', 'lang/contents/');

    this._view = new ContentsMenuView(configs);
    this._view.addEventListener(MEDIA_CONTENTS, this._clickMediaContents, this);
    this._view.addEventListener(PREV, this.clickPrev, this);

    this._parentContext = configs.parentContext;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype.clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

prototype._clickMediaContents = function() {
    var controller;
    var query = {};

    query.parentContext = this;
    controller = new ContentsController(query);
    controller.start();
};

}());
