/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule public-folder-view
 */

(function() {
var PublicFolderView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var $ = dixim.ctt.jQuery;
var UiUtils = dixim.common.UiUtils;
var Template = dixim.ctt.util.Template

/**
 * @class PublicFolderView
 * @constructor
 * @param {Object} configs
 */
PublicFolderView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};
dixim.inherit(PublicFolderView, EventTarget);
dixim.server.PublicFolderView = PublicFolderView;
prototype = PublicFolderView.prototype;
superConstructor = PublicFolderView.superConstructor;

var SELECT = 'select';
var DELETE = 'delete';
var CHANGE = 'change';
var ADD = 'add';
var SYNC = 'sync';
var PREV = 'prev';

var SEPARATE = Template.SEPARATE;

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'public-folder'].join('');

    this._title = _('server_menu_public_folder');
    this._uiUtils = UiUtils;
    this._selectedData = {};
};

/**
 * @method show
 */
prototype.show = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<div id="sharedFolderList">',
        '<table class="tbl_list">',
        '<colgroup>',
        '<col span="1" class="checkbox">',
        '<col span="1" class="list_info">',
        '</colgroup>',
        '</table>',
        '</div>',
        '</div>',
        '</div>',
    ].join(''));

    this._uiUtils.cleanActionSettingBar();
    this._uiUtils.cleanActionBar();
    this._uiUtils.setActionBar('ab_select', dixim.proxy(this._clickSelect, this));
    this._uiUtils.setActionBar('ab_delete', dixim.proxy(this._clickDelete, this));
    this._uiUtils.setActionBar('ab_edit', dixim.proxy(this._clickChange, this));
    this._uiUtils.setActionBar('ab_append', dixim.proxy(this._clickAdd, this));
    this._uiUtils.setActionBar('ab_sync', dixim.proxy(this._clickSync, this));

    $('.art_tit').text(this._title);
    $('.btn_prev').show().one('click', dixim.proxy(this._clickPrev, this));
};

/**
 * @method hide
 */
prototype.hide = function() {
    $('.rootPage').empty();
};

prototype.addRow = function(sharedFolder, path) {
    var media = _(['server_public_folder_media_', sharedFolder.mediaType].join(''));
    var rowSelector;

    $('#sharedFolderList table').append([
        '<tr>',
        '<td>',
        '<label class="select-pointer">',
        '<input type="checkbox" />', '<span>', '</span>',
        '</label>',
        '</td>',
        '<td>',
        '<h4 class="txt_m">', path, '</h4>',
        '<div class="list_detail txt_s">',
        '<p>', media, '</p>',
        '</div>',
        '</td>',
        '</tr>',
    ].join(''));

    rowSelector = $('#sharedFolderList table tr:last-child');
    rowSelector.find('[type="checkbox"]').on('change', sharedFolder, dixim.proxy(this._changeCheckbox, this));
};

prototype._changeCheckbox = function(e) {
    if (e.currentTarget.checked) {
        this._selectedData[e.data.id] = e.data;
    } else {
        delete this._selectedData[e.data.id];
    }
};

prototype.noRow = function() {
    this.error(_('server_public_folder_no_folder'));
};

prototype.error = function(text) {
    $('#public-folder-error').remove();
    $('.contents_inner').append([
        '<div id="public-folder-error" class="error-text-field txt_none">',
        '<span>', text, '</span>',
        '</div>',
    ].join(''));
};

prototype.switchSelect = function() {
    var numberOfNotChecked = $('.tbl_list [type="checkbox"]').not(':checked').length;

    if (numberOfNotChecked > 0) {
        $('.tbl_list [type="checkbox"]').not(':checked').trigger('click');
    } else {
        $('.tbl_list [type="checkbox"]:checked').trigger('click');
    }
};

prototype.cleanList = function() {
    $('#sharedFolderList table tr').remove();
    this._selectedData = {};
};

prototype._clickSelect = function() {
    this.dispatchEvent(new Event(SELECT));
};

prototype._clickDelete = function() {
    var list = [];

    for (var key in this._selectedData) {
        list.push(this._selectedData[key]);
    }
    this.dispatchEvent(new Event(DELETE, {sharedFolders: list}));
};

prototype._clickChange = function() {
    var list = [];

    for (var key in this._selectedData) {
        list.push(this._selectedData[key]);
    }
    this.dispatchEvent(new Event(CHANGE, {sharedFolders: list}));
};

prototype._clickAdd = function() {
    this.dispatchEvent(new Event(ADD));
};

prototype._clickSync = function() {
    var list = [];

    for (var key in this._selectedData) {
        list.push(this._selectedData[key]);
    }
    this.dispatchEvent(new Event(SYNC, {sharedFolders: list}));
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

}());
